@@ -23,6 +23,3 @@ class TextMsg:
         self.mention_here: bool = extra['mention_here']
         self.author: User = User(extra['author'])
 
-
-class MsgCtx:
-    pass
