@@ -1,4 +1,4 @@
 from .Command import Command
-from .Message import MsgCtx, TextMsg
+from .Message import TextMsg
 from .User import User
 from .hardcoded import *
